Examples
====================

.. note::

    You can install all of the Python library requirements needed to run the example notebooks with:
    `pip install datarobot[examples]`.

Downloads
*********

:download:`Download all the notebooks and the supporting scripts and data files <../datarobot_examples.zip>`

Download an open source `font <https://github.com/googlei18n/noto-cjk/raw/master/NotoSansCJKjp-Regular.otf>`_ that supports the Japanese text example (only required in the Advanced Model Insights notebook).

Example Jupyter Notebooks
*************************

.. toctree::
   :maxdepth: 2

   lending_club/Predicting_Bad_Loans.ipynb
   airline_ontime_example/Modeling_Airline_Delay.ipynb
   advanced_model_insights/Advanced_Model_Insights.ipynb
   advanced_tuning/Advanced_Tuning_Parameters.ipynb
   time_series/Time_Series_Modeling.ipynb
